@@ -21,7 +21,10 @@ if config.HAVE_FENICS:
     from pymor.bindings.fenics import FenicsVectorSpace
 
 if config.HAVE_DEALII:
-    from pydealii.pymor.vectorarray import DealIIVectorSpace
+    from pymor_dealii.pymor.vectorarray import DealIIVectorSpace
+
+if config.HAVE_DUNEGDT:
+    from pymor.bindings.dunegdt import DuneXTVectorSpace
 
 if config.HAVE_NGSOLVE:
     import ngsolve as ngs
@@ -141,6 +144,11 @@ if config.HAVE_DEALII:
         return [(DealIIVectorSpace(d), ar) for d, ar in zip(dims, np_data_list)]
     _other_vector_space_types.append('dealii')
 
+if config.HAVE_DUNEGDT:
+    def _dunegdt_vector_spaces(draw, np_data_list, compatible, count, dims):
+        return [(DuneXTVectorSpace(d), ar) for d, ar in zip(dims, np_data_list)]
+    _other_vector_space_types.append('dunegdt')
+
 
 _picklable_vector_space_types = ['numpy', 'numpy_list', 'block']
 
@@ -246,20 +254,15 @@ def valid_inds(v, length=None, random_module=None):
         yield []
 
 
-# TODO: remove old assumptions on slice values
-def _filtered_slices(length):
-    def _filter(sl):
-        return sl.step is None or sl.step > 0
-    return hyst.slices(length).filter(_filter)
-
-
 @hyst.composite
 def valid_indices(draw, array_strategy, length=None):
     v = draw(array_strategy)
     ints = hyst.integers(min_value=-len(v), max_value=max(len(v)-1, 0))
     indices = hyst.nothing()
     if length is None:
-        indices = indices | hyst.just([]) | hyst.lists(ints, max_size=2*len(v)) | _filtered_slices(len(v))
+        indices = indices | hyst.just([]) | hyst.lists(ints, max_size=2*len(v))
+    else:
+        indices = indices | hyst.slices(length)
     if len(v) > 0:
         inds = [-len(v), 0, len(v) - 1]
         if len(v) == length:
@@ -309,13 +312,13 @@ def st_valid_inds_of_same_length(draw, v1, v2):
     # `| hynp.integer_array_indices(shape=(LEN_X,))`
     if len1 == len2:
         ints = hyst.integers(min_value=-len1, max_value=max(len1 - 1, 0))
-        slicer = _filtered_slices(len1) | hyst.lists(ints, max_size=len1)
+        slicer = hyst.slices(len1) | hyst.lists(ints, max_size=len1)
         ret = ret | hyst.tuples(hyst.shared(slicer, key="st_valid_inds_of_same_length"),
                                 hyst.shared(slicer, key="st_valid_inds_of_same_length"))
     if len1 > 0 and len2 > 0:
         mlen = min(len1, len2)
         ints = hyst.integers(min_value=-mlen, max_value=max(mlen - 1, 0))
-        slicer = _filtered_slices(mlen) | ints | hyst.lists(ints, max_size=mlen)
+        slicer = hyst.slices(mlen) | ints | hyst.lists(ints, max_size=mlen)
         ret = ret | hyst.tuples(hyst.shared(slicer, key="st_valid_inds_of_same_length_uneven"),
                                 hyst.shared(slicer, key="st_valid_inds_of_same_length_uneven"))
     return draw(ret)
@@ -375,8 +378,8 @@ def st_valid_inds_of_different_length(draw, v1, v2):
 
     len1, len2 = len(v1), len(v2)
     # TODO we should include integer arrays here
-    val1 = _filtered_slices(len1)  # | hynp.integer_array_indices(shape=(len1,))
-    val2 = _filtered_slices(len2)  # | hynp.integer_array_indices(shape=(len1,))
+    val1 = hyst.slices(len1)  # | hynp.integer_array_indices(shape=(len1,))
+    val2 = hyst.slices(len2)  # | hynp.integer_array_indices(shape=(len1,))
     ret = hyst.tuples(val1, val2).filter(_filter)
     return draw(ret)
 
